﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Windows.Controls;

using DomainModel;

using IdeaBlade.EntityModel;

namespace PocoApp {

  public partial class MainPage : UserControl {
    public MainPage() {
      InitializeComponent();
      CreateEntityManager();
      Login();
    }

    private void Login() {
      var cred = new LoginCredential("demo1", "demo2", "demo3");

      WriteMessage("Logging in ...");

      _mgr.LoginAsync(
        cred,
        args => {
          if (args.Error != null) {
            WriteMessage(args.Error.Message);
          } else {
            WriteMessage("Logged in");
            LoadData();
          }
        },
        null);
    }

    private void CreateEntityManager() {
      _mgr = new EntityManager();
    }

    #region LoadData

    private void LoadData() {
      _mgr.ExecuteQueryAsync<State>(_mgr.States().Where(s => s.Lower49), GotStates, null);
    }

    void GotStates(EntityQueryOperation<State> op) {
      _states.Clear();
      if (op.Error != null) {
        WriteMessage(op.Error.Message);
      } else {
        var results = op.Results as IEnumerable;
        foreach (State aState in results) {
          _states.Add(aState);
        }
        _statesDataGrid.ItemsSource = _states;
        ReportFetchCount(results);
      }
    }

    #endregion LoadData

    private void ReportFetchCount(IEnumerable results) {
      if (results == null) {
        WriteMessage("Fetch failed");
      } else {
        WriteMessage(string.Format("Retrieved {0} items.", results.Cast<Object>().Count()));
      }
    }

    public void WriteMessage(string msg) {
      _statusTextBlock.Text += Environment.NewLine + msg;
    }

    #region Private Fields
    EntityManager _mgr;
    List<State> _states = new List<State>();
    #endregion Private Fields
  }
}
