﻿Imports System
Imports System.Collections.Generic
Imports System.Linq
Imports System.ComponentModel.DataAnnotations
Imports IdeaBlade.EntityModel
Imports System.Runtime.Serialization
Imports System.ComponentModel

' POCO types must be "known" types, and must be serializable.
' Indicating that this is a "known" type allows instances of the type to be queried and saved in an n-tier environment, such as Silverlight.
' There are several ways to identify the type as a "known" type to DevForce:
' (1) Decorate a property (or multiple properties) with the Key attribute; or
' (2) Decorate the type with the KnownType attribute; or
' (3) Implement the IKnownType interface; or
' (4) Implement the IKnownTypeProvider interface
'
' The class must also be serializable:  
'   1) Mark the class and members with the DataContract and DataMember attributes, or
'   2) The public properties of the class will be serializable if the class has a public parameterless constructor.  This technique is
'      used here.
Public Class State
  Implements IKnownType, IHasPocoEntityAspect, INotifyPropertyChanged

  Public Sub New()
  End Sub

  <Key()> _
  Public Property Abbrev() As String
    Get
      Return _abbrev
    End Get
    Set(ByVal value As String)
      _abbrev = value
    End Set
  End Property

  Public Property Name() As String
    Get
      Return _name
    End Get
    Set(ByVal value As String)
      _name = value
    End Set
  End Property

  Public Property Lower49() As Boolean
    Get
      Return _lower49
    End Get
    Set(ByVal value As Boolean)
      _lower49 = value
    End Set
  End Property

#Region "Private Fields"
  Private _abbrev As String
  Private _name As String
  Private _lower49 As Boolean
#End Region

#Region "IHasPocoEntityAspect Members"
  'We don't want to serialize EntityAspect here as EntityAspect is not serializable
  <Display(AutoGenerateField:=False)> _
  <IgnoreDataMember()> _
  Public Property EntityAspect() As IdeaBlade.EntityModel.EntityAspect _
    Implements IHasPocoEntityAspect.EntityAspect
#End Region

#Region "INotifyPropertyChanged Members"
  ''' <summary>
  ''' This interface implementation is needed if you want EntityManager to automatically listen
  ''' to any property change.
  ''' </summary>
  Public Event PropertyChanged As PropertyChangedEventHandler _
    Implements INotifyPropertyChanged.PropertyChanged

  Protected Sub OnPropertyChanged(propertyName As [String])
    Dim args = New PropertyChangedEventArgs(propertyName)
    RaiseEvent PropertyChanged(Me, args)
  End Sub
#End Region

End Class

